# OSGRMATT - Open Selenium with optionaly Grid ReMote and Api Test Tools
simple tool to create tests with selenium or api

# How to use:
1) ```pip install OSGRMATT```
2) ```osgrmatt create_api_project``` to create api tests project or ```osgrmatt create_selenium_project``` to create selenium project
3) create .env file
4) add env variable ```TOKEN=your_telegram_bot_token```
5) add env variable ```CHAT_ID=your_telegram_chat_id```